function ent=enth2(ti,tf,Icp)
% enth2 - Finds sensible enthalpy change for one compound in J/mol
% 
% enth2 finds the sensible enthalpy change from ti to tf, with
%      the units for ti and tf and ent set by the constants in Icp.
%      It returns an answer in J/mol 
% 
% function ent=enth2(ti,tf,Icp)
% Arguments:
%      ti      the initial temperature in K
%      tf      the final temperature in K
%      Icp     a single vector of constants, where the integral
%              of the specific heat is:
%              Icp(1)*t^N + Icp(2)*t^N-1 +....+ Icp(N-1)*t.
% 	
% The units for ti, tf, and ent are set by the constants in Icp
%      by executing start301.
%
% See also enth1, enth3
%
% Example: use start301 to specify compounds C6H6
%     and water.
% >> enth2(300,400,intcp2('v',1))
%
% OKB, revised help by TYLC, SHD, & MAH
Icp=[Icp,0];
pv=polyval(Icp,[ti,tf]);
ent=pv(2)-pv(1);
